@@ -19,12 +19,10 @@
 
 import io
 import re
-import sys
 
 from mox3 import mox
 from mox3.tests import mox_helper
 
-import six
 import testtools
 
 
@@ -285,7 +283,7 @@ class StrContainsTest(testtools.TestCase):
         self.assertFalse(mox.StrContains("AAA") == "hello world")
 
     def testMultipleMatches(self):
-        """Should return True if there are multiple occurances of substring."""
+        """Should return True if there are multiple occurrences of substring"""
         self.assertTrue(mox.StrContains("abc") == "ababcabcabcababc")
 
 
@@ -766,27 +764,12 @@ class MockAnythingTest(testtools.TestCase):
 
     def testIsReprable(self):
         """Test that MockAnythings can be repr'd without causing a failure."""
-        self.assertTrue('MockAnything' in repr(self.mock_object))
+        self.assertIn('MockAnything', repr(self.mock_object))
 
 
 class MethodCheckerTest(testtools.TestCase):
     """Tests MockMethod's use of MethodChecker method."""
 
-    def testUnboundMethodsRequiresInstance(self):
-        # SKIP TEST IN PYTHON 2.x (Ugly hack for python 2.6)
-        # REASON: semantics for unbound methods has changed only in Python 3
-        #     so this test in earlier versions is invald
-        if sys.version_info < (3, 0):
-            return
-
-        instance = CheckCallTestClass()
-        method = mox.MockMethod('NoParameters', [], False,
-                                CheckCallTestClass.NoParameters)
-
-        self.assertRaises(AttributeError, method)
-        method(instance)
-        self.assertRaises(AttributeError, method, instance, 1)
-
     def testNoParameters(self):
         method = mox.MockMethod('NoParameters', [], False,
                                 CheckCallTestClass.NoParameters,
@@ -978,27 +961,27 @@ class MockObjectTest(testtools.TestCase):
 
     def testFindValidMethods(self):
         """Mock should be able to mock all public methods."""
-        self.assertTrue('ValidCall' in self.mock_object._known_methods)
-        self.assertTrue('OtherValidCall' in self.mock_object._known_methods)
-        self.assertTrue('MyClassMethod' in self.mock_object._known_methods)
-        self.assertTrue('MyStaticMethod' in self.mock_object._known_methods)
-        self.assertTrue('_ProtectedCall' in self.mock_object._known_methods)
-        self.assertTrue('__PrivateCall' not in self.mock_object._known_methods)
-        self.assertTrue(
-            '_TestClass__PrivateCall' in self.mock_object._known_methods)
+        self.assertIn('ValidCall', self.mock_object._known_methods)
+        self.assertIn('OtherValidCall', self.mock_object._known_methods)
+        self.assertIn('MyClassMethod', self.mock_object._known_methods)
+        self.assertIn('MyStaticMethod', self.mock_object._known_methods)
+        self.assertIn('_ProtectedCall', self.mock_object._known_methods)
+        self.assertNotIn('__PrivateCall', self.mock_object._known_methods)
+        self.assertIn(
+            '_TestClass__PrivateCall', self.mock_object._known_methods)
 
     def testFindsSuperclassMethods(self):
         """Mock should be able to mock superclasses methods."""
         self.mock_object = mox.MockObject(ChildClass)
-        self.assertTrue('ValidCall' in self.mock_object._known_methods)
-        self.assertTrue('OtherValidCall' in self.mock_object._known_methods)
-        self.assertTrue('MyClassMethod' in self.mock_object._known_methods)
-        self.assertTrue('ChildValidCall' in self.mock_object._known_methods)
+        self.assertIn('ValidCall', self.mock_object._known_methods)
+        self.assertIn('OtherValidCall', self.mock_object._known_methods)
+        self.assertIn('MyClassMethod', self.mock_object._known_methods)
+        self.assertIn('ChildValidCall', self.mock_object._known_methods)
 
     def testAccessClassVariables(self):
         """Class variables should be accessible through the mock."""
-        self.assertTrue('SOME_CLASS_VAR' in self.mock_object._known_vars)
-        self.assertTrue('_PROTECTED_CLASS_VAR' in self.mock_object._known_vars)
+        self.assertIn('SOME_CLASS_VAR', self.mock_object._known_vars)
+        self.assertIn('_PROTECTED_CLASS_VAR', self.mock_object._known_vars)
         self.assertEqual('test_value', self.mock_object.SOME_CLASS_VAR)
 
     def testEquals(self):
@@ -1200,7 +1183,7 @@ class MockObjectTest(testtools.TestCase):
 
         dummy._Replay()
 
-        self.assertTrue('X' in dummy)
+        self.assertIn('X', dummy)
 
         dummy._Verify()
 
@@ -1908,7 +1891,6 @@ class MoxTest(testtools.TestCase):
     # FIXME(dhellmann): Skip this test until someone can debug why it
     # fails on python 3.4.
 
-    @testtools.skipIf(six.PY3, "This test needs to be fixed for python 3")
     def testStubOutClass_OldStyle(self):
         """Test a mocked class whose __init__ returns a Mock."""
         self.mox.StubOutWithMock(mox_helper, 'TestClassFromAnotherModule')
